@@ -46,7 +46,7 @@ class BaseConnectionConfig(
     ] = None
     options: Annotated[
         OptionalStringToAnyDict,
-        Field(default_factory=dict, description="Additional connection options"),
+        Field(None, description="Additional connection options"),
     ] = None
 
     @model_validator(mode="after")
@@ -203,7 +203,159 @@ class BaseConnectionConfig(
             )
 
 
-ConnectionConfigT = TypeVar("ConnectionConfigT", bound=BaseConnectionConfig)
+class ElasticsearchConnectionConfig(
+    BaseConnectionConfig[
+        Literal[Driver.ELASTICSEARCH], OptionalString, OptionalString, str, int, str
+    ]
+):
+    driver: Literal[Driver.ELASTICSEARCH] = Driver.ELASTICSEARCH
+    port: Annotated[int, Field(9200, description="Elasticsearch port")] = 9200
+    username: Annotated[
+        OptionalString, Field(None, description="Elasticsearch username")
+    ] = None
+    password: Annotated[
+        OptionalString, Field(None, description="Elasticsearch password")
+    ] = None
+    database: Annotated[
+        str, Field("_all", description="Elasticsearch index pattern")
+    ] = "_all"
+
+    # Elasticsearch-specific options
+    scheme: Annotated[
+        ElasticsearchScheme,
+        Field(ElasticsearchScheme.HTTP, description="Connection scheme (http/https)"),
+    ] = ElasticsearchScheme.HTTP
+
+    @model_validator(mode="after")
+    def validate_https_consistency(self):
+        """Validate HTTPS and SSL consistency"""
+        if self.scheme == "https" and self.ssl is False:
+            raise ValueError("Cannot use https scheme with ssl=False")
+        return self
+
+    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
+        """Elasticsearch URL format - HTTP-based, same for async/sync."""
+        # Elasticsearch uses HTTP/HTTPS, async/sync is handled by the client library
+
+        auth_part = ""
+
+        if self.username and self.password:
+            encoded_user = self._safe_encode_credential(self.username)
+            encoded_pass = self._safe_encode_credential(self.password)
+            auth_part = f"{encoded_user}:{encoded_pass}@"
+
+        base_url = f"{self.scheme}://{auth_part}{self.host}:{self.port}"
+
+        # Elasticsearch doesn't typically use database in URL path like SQL databases
+        # The 'database' field might represent default index, but it's usually specified per request
+
+        # Add Elasticsearch-specific options as URL params if needed
+        es_options = {}
+        return base_url + self._make_options_string(es_options)
+
+
+class MongoConnectionConfig(
+    BaseConnectionConfig[
+        Literal[Driver.MONGODB], OptionalString, OptionalString, str, int, str
+    ]
+):
+    driver: Literal[Driver.MONGODB] = Driver.MONGODB
+    port: Annotated[int, Field(27017, description="Mongo port")] = 27017
+    username: Annotated[OptionalString, Field(None, description="Mongo username")] = (
+        None
+    )
+    password: Annotated[OptionalString, Field(None, description="Mongo password")] = (
+        None
+    )
+
+    # Mongo-specific options
+    auth_source: Annotated[
+        OptionalString, Field("admin", description="Authentication database")
+    ] = "admin"
+    read_preference: Annotated[
+        Optional[MongoReadPreference],
+        Field(MongoReadPreference.PRIMARY, description="Read preference"),
+    ] = MongoReadPreference.PRIMARY
+    replica_set: Annotated[
+        OptionalString, Field(None, description="Replica set name")
+    ] = None
+
+    @model_validator(mode="after")
+    def validate_auth_consistency(self):
+        """Both username and password should be provided together"""
+        if (self.username is None) != (self.password is None):
+            raise ValueError(
+                "Username and password must both be provided or both be None"
+            )
+        return self
+
+    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
+        """Mongo URL format - Mongo driver handles async/sync internally."""
+        # Mongo uses the same URL format for both async and sync
+        # The async/sync behavior is determined by the client library used
+
+        auth_part = ""
+        if self.username and self.password:
+            encoded_user = self._safe_encode_credential(self.username)
+            encoded_pass = self._safe_encode_credential(self.password)
+            auth_part = f"{encoded_user}:{encoded_pass}@"
+
+        base_url = f"mongodb://{auth_part}{self.host}:{self.port}/{self.database}"
+
+        # Add Mongo-specific options
+        mongo_options = {
+            "authSource": self.auth_source,
+            "replicaSet": self.replica_set,
+            "readPreference": self.read_preference,
+            "ssl": self.ssl,
+        }
+        return base_url + self._make_options_string(mongo_options)
+
+
+class RedisConnectionConfig(
+    BaseConnectionConfig[
+        Literal[Driver.REDIS], OptionalString, OptionalString, str, int, int
+    ]
+):
+    driver: Literal[Driver.REDIS] = Driver.REDIS
+    port: Annotated[int, Field(6379, description="Redis port")] = 6379
+    database: Annotated[
+        int, Field(0, description="Redis database number (0-15)", ge=0, le=15)
+    ] = 0
+    username: Annotated[
+        OptionalString, Field(None, description="Redis username (Redis 6+)")
+    ] = None
+    password: Annotated[OptionalString, Field(None, description="Redis password")] = (
+        None
+    )
+
+    # Redis-specific options
+    decode_responses: Annotated[
+        bool, Field(True, description="Decode responses to strings")
+    ] = True
+    max_connections: Annotated[
+        OptionalInteger, Field(None, ge=1, description="Max connections in pool")
+    ] = None
+
+    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
+        """Redis URL format with async/sync support."""
+        # Redis URL format is the same, but different libraries handle async/sync
+        # redis-py for sync, aioredis for async
+
+        auth_part = ""
+        if self.username and self.password:
+            encoded_user = self._safe_encode_credential(self.username)
+            encoded_pass = self._safe_encode_credential(self.password)
+            auth_part = f"{encoded_user}:{encoded_pass}@"
+        elif self.password:
+            encoded_pass = self._safe_encode_credential(self.password)
+            auth_part = f":{encoded_pass}@"
+
+        base_url = f"redis://{auth_part}{self.host}:{self.port}/{self.database}"
+
+        # Add Redis-specific options
+        redis_options = {"decode_responses": self.decode_responses}
+        return base_url + self._make_options_string(redis_options)
 
 
 class MySQLConnectionConfig(
@@ -392,172 +544,17 @@ class SQLServerConnectionConfig(
         return self.model_dump(include={"echo"}, exclude_none=True)
 
 
-class ElasticsearchConnectionConfig(
-    BaseConnectionConfig[
-        Literal[Driver.ELASTICSEARCH], OptionalString, OptionalString, str, int, str
-    ]
-):
-    driver: Literal[Driver.ELASTICSEARCH] = Driver.ELASTICSEARCH
-    port: Annotated[int, Field(9200, description="Elasticsearch port")] = 9200
-    username: Annotated[
-        OptionalString, Field(None, description="Elasticsearch username")
-    ] = None
-    password: Annotated[
-        OptionalString, Field(None, description="Elasticsearch password")
-    ] = None
-    database: Annotated[
-        str, Field("_all", description="Elasticsearch index pattern")
-    ] = "_all"
-
-    # Elasticsearch-specific options
-    scheme: Annotated[
-        ElasticsearchScheme,
-        Field(ElasticsearchScheme.HTTP, description="Connection scheme (http/https)"),
-    ] = ElasticsearchScheme.HTTP
-
-    @model_validator(mode="after")
-    def validate_https_consistency(self):
-        """Validate HTTPS and SSL consistency"""
-        if self.scheme == "https" and self.ssl is False:
-            raise ValueError("Cannot use https scheme with ssl=False")
-        return self
-
-    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
-        """Elasticsearch URL format - HTTP-based, same for async/sync."""
-        # Elasticsearch uses HTTP/HTTPS, async/sync is handled by the client library
-
-        auth_part = ""
-
-        if self.username and self.password:
-            encoded_user = self._safe_encode_credential(self.username)
-            encoded_pass = self._safe_encode_credential(self.password)
-            auth_part = f"{encoded_user}:{encoded_pass}@"
-
-        base_url = f"{self.scheme}://{auth_part}{self.host}:{self.port}"
-
-        # Elasticsearch doesn't typically use database in URL path like SQL databases
-        # The 'database' field might represent default index, but it's usually specified per request
-
-        # Add Elasticsearch-specific options as URL params if needed
-        es_options = {}
-        return base_url + self._make_options_string(es_options)
-
-
-class MongoConnectionConfig(
-    BaseConnectionConfig[
-        Literal[Driver.MONGODB], OptionalString, OptionalString, str, int, str
-    ]
-):
-    driver: Literal[Driver.MONGODB] = Driver.MONGODB
-    port: Annotated[int, Field(27017, description="Mongo port")] = 27017
-    username: Annotated[OptionalString, Field(None, description="Mongo username")] = (
-        None
-    )
-    password: Annotated[OptionalString, Field(None, description="Mongo password")] = (
-        None
-    )
-
-    # Mongo-specific options
-    auth_source: Annotated[
-        OptionalString, Field("admin", description="Authentication database")
-    ] = "admin"
-    read_preference: Annotated[
-        Optional[MongoReadPreference],
-        Field(MongoReadPreference.PRIMARY, description="Read preference"),
-    ] = MongoReadPreference.PRIMARY
-    replica_set: Annotated[
-        OptionalString, Field(None, description="Replica set name")
-    ] = None
-
-    @model_validator(mode="after")
-    def validate_auth_consistency(self):
-        """Both username and password should be provided together"""
-        if (self.username is None) != (self.password is None):
-            raise ValueError(
-                "Username and password must both be provided or both be None"
-            )
-        return self
-
-    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
-        """Mongo URL format - Mongo driver handles async/sync internally."""
-        # Mongo uses the same URL format for both async and sync
-        # The async/sync behavior is determined by the client library used
-
-        auth_part = ""
-        if self.username and self.password:
-            encoded_user = self._safe_encode_credential(self.username)
-            encoded_pass = self._safe_encode_credential(self.password)
-            auth_part = f"{encoded_user}:{encoded_pass}@"
-
-        base_url = f"mongodb://{auth_part}{self.host}:{self.port}/{self.database}"
-
-        # Add Mongo-specific options
-        mongo_options = {
-            "authSource": self.auth_source,
-            "replicaSet": self.replica_set,
-            "readPreference": self.read_preference,
-            "ssl": self.ssl,
-        }
-        return base_url + self._make_options_string(mongo_options)
-
-
-class RedisConnectionConfig(
-    BaseConnectionConfig[
-        Literal[Driver.REDIS], OptionalString, OptionalString, str, int, int
-    ]
-):
-    driver: Literal[Driver.REDIS] = Driver.REDIS
-    port: Annotated[int, Field(6379, description="Redis port")] = 6379
-    database: Annotated[
-        int, Field(0, description="Redis database number (0-15)", ge=0, le=15)
-    ] = 0
-    username: Annotated[
-        OptionalString, Field(None, description="Redis username (Redis 6+)")
-    ] = None
-    password: Annotated[OptionalString, Field(None, description="Redis password")] = (
-        None
-    )
-
-    # Redis-specific options
-    decode_responses: Annotated[
-        bool, Field(True, description="Decode responses to strings")
-    ] = True
-    max_connections: Annotated[
-        OptionalInteger, Field(None, ge=1, description="Max connections in pool")
-    ] = None
-
-    def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
-        """Redis URL format with async/sync support."""
-        # Redis URL format is the same, but different libraries handle async/sync
-        # redis-py for sync, aioredis for async
-
-        auth_part = ""
-        if self.username and self.password:
-            encoded_user = self._safe_encode_credential(self.username)
-            encoded_pass = self._safe_encode_credential(self.password)
-            auth_part = f"{encoded_user}:{encoded_pass}@"
-        elif self.password:
-            encoded_pass = self._safe_encode_credential(self.password)
-            auth_part = f":{encoded_pass}@"
-
-        base_url = f"redis://{auth_part}{self.host}:{self.port}/{self.database}"
-
-        # Add Redis-specific options
-        redis_options = {"decode_responses": self.decode_responses}
-        return base_url + self._make_options_string(redis_options)
-
-
 # Factory function with better type hints
 def create_connection_config(driver: Driver, **kwargs) -> BaseConnectionConfig:
     """Factory to create the appropriate connection config based on driver"""
     config_map = {
-        Driver.POSTGRESQL: PostgreSQLConnectionConfig,
-        Driver.MYSQL: MySQLConnectionConfig,
-        Driver.SQLITE: SQLiteConnectionConfig,
+        Driver.ELASTICSEARCH: ElasticsearchConnectionConfig,
         Driver.MONGODB: MongoConnectionConfig,
         Driver.REDIS: RedisConnectionConfig,
+        Driver.MYSQL: MySQLConnectionConfig,
+        Driver.POSTGRESQL: PostgreSQLConnectionConfig,
+        Driver.SQLITE: SQLiteConnectionConfig,
         Driver.MSSQL: SQLServerConnectionConfig,
-        Driver.ELASTICSEARCH: ElasticsearchConnectionConfig,
     }
 
     config_class = config_map.get(driver)
@@ -565,3 +562,15 @@ def create_connection_config(driver: Driver, **kwargs) -> BaseConnectionConfig:
         raise ValueError(f"Unsupported driver: {driver}")
 
     return config_class(driver=driver, **kwargs)
+
+
+ConnectionConfigT = TypeVar(
+    "ConnectionConfigT",
+    ElasticsearchConnectionConfig,
+    MongoConnectionConfig,
+    RedisConnectionConfig,
+    MySQLConnectionConfig,
+    PostgreSQLConnectionConfig,
+    SQLiteConnectionConfig,
+    SQLServerConnectionConfig,
+)
