@@ -1,10 +1,35 @@
 from enum import StrEnum
+from maleo.types.string import ListOfStrings
+
+
+class CacheOrigin(StrEnum):
+    CLIENT = "client"
+    SERVICE = "service"
+
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
+
+
+class CacheLayer(StrEnum):
+    REPOSITORY = "repository"
+    SERVICE = "service"
+    CONTROLLER = "controller"
+    MIDDLEWARE = "middleware"
+
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
 
 
 class Connection(StrEnum):
     ASYNC = "async"
     SYNC = "sync"
 
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
+
 
 class Driver(StrEnum):
     # SQL Databases - Most Popular
@@ -13,40 +38,20 @@ class Driver(StrEnum):
     SQLITE = "sqlite"
 
     # SQL Databases - Enterprise
-    # ORACLE = "oracle"
-    MSSQL = "mssql"  # SQL Server
-    # MARIADB = "mariadb"
+    MSSQL = "mssql"
 
     # NoSQL Document Stores
     MONGODB = "mongodb"
-    # COUCHDB = "couchdb"
 
     # NoSQL Key-Value
     REDIS = "redis"
-    # DYNAMODB = "dynamodb"  # AWS
-
-    # NoSQL Column Family
-    # CASSANDRA = "cassandra"
-    # HBASE = "hbase"
-
-    # NoSQL Graph
-    # NEO4J = "neo4j"
-    # ARANGODB = "arangodb"
-
-    # Time Series
-    # INFLUXDB = "influxdb"
-    # TIMESCALEDB = "timescaledb"  # PostgreSQL extension
-
-    # In-Memory
-    # MEMCACHED = "memcached"
 
     # Search Engines
     ELASTICSEARCH = "elasticsearch"
-    # OPENSEARCH = "opensearch"
 
-    # Cloud Native
-    # FIRESTORE = "firestore"  # Google
-    # COSMOSDB = "cosmosdb"  # Azure
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
 
 
 class PostgreSQLSSLMode(StrEnum):
@@ -57,6 +62,10 @@ class PostgreSQLSSLMode(StrEnum):
     VERIFY_CA = "verify-ca"
     VERIFY_FULL = "verify-full"
 
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
+
 
 class MySQLCharset(StrEnum):
     UTF8 = "utf8"
@@ -64,6 +73,10 @@ class MySQLCharset(StrEnum):
     LATIN1 = "latin1"
     ASCII = "ascii"
 
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
+
 
 class MongoReadPreference(StrEnum):
     PRIMARY = "primary"
@@ -72,14 +85,26 @@ class MongoReadPreference(StrEnum):
     SECONDARY_PREFERRED = "secondaryPreferred"
     NEAREST = "nearest"
 
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
+
 
 class ElasticsearchScheme(StrEnum):
     HTTP = "http"
     HTTPS = "https"
 
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
+
 
 class PoolingStrategy(StrEnum):
     FIXED = "fixed"
     DYNAMIC = "dynamic"
     OVERFLOW = "overflow"
     QUEUE = "queue"
+
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
