@@ -8,7 +8,7 @@ from .config import (
     PostgreSQLConfig,
     SQLiteConfig,
     SQLServerConfig,
-    ConfigT,
+    DatabaseConfigT,
 )
 from .managers import (
     ElasticsearchManager,
@@ -18,7 +18,7 @@ from .managers import (
     PostgreSQLManager,
     SQLiteManager,
     SQLServerManager,
-    ManagerT,
+    DatabaseManagerT,
 )
 from .types import DeclarativeBaseT
 
@@ -26,14 +26,14 @@ from .types import DeclarativeBaseT
 class Handler(
     BaseModel,
     Generic[
-        ConfigT,
-        ManagerT,
+        DatabaseConfigT,
+        DatabaseManagerT,
     ],
 ):
     model_config = ConfigDict(arbitrary_types_allowed=True)
 
-    config: Annotated[ConfigT, Field(..., description="Config")]
-    manager: Annotated[ManagerT, Field(..., description="Manager")]
+    config: Annotated[DatabaseConfigT, Field(..., description="Config")]
+    manager: Annotated[DatabaseManagerT, Field(..., description="Manager")]
 
 
 HandlerT = TypeVar("HandlerT", bound=Handler)
@@ -120,28 +120,36 @@ class NoSQLHandlers(
 NoSQLHandlersT = TypeVar("NoSQLHandlersT", bound=Optional[NoSQLHandlers])
 
 
-class MySQLHandlers(BaseHandlers[MySQLHandler]):
+class MySQLHandlers(
+    BaseHandlers[MySQLHandler[DeclarativeBaseT]], Generic[DeclarativeBaseT]
+):
     pass
 
 
 MySQLHandlersT = TypeVar("MySQLHandlersT", bound=Optional[MySQLHandlers])
 
 
-class PostgreSQLHandlers(BaseHandlers[PostgreSQLHandler]):
+class PostgreSQLHandlers(
+    BaseHandlers[PostgreSQLHandler[DeclarativeBaseT]], Generic[DeclarativeBaseT]
+):
     pass
 
 
 PostgreSQLHandlersT = TypeVar("PostgreSQLHandlersT", bound=Optional[PostgreSQLHandlers])
 
 
-class SQLiteHandlers(BaseHandlers[SQLiteHandler]):
+class SQLiteHandlers(
+    BaseHandlers[SQLiteHandler[DeclarativeBaseT]], Generic[DeclarativeBaseT]
+):
     pass
 
 
 SQLiteHandlersT = TypeVar("SQLiteHandlersT", bound=Optional[SQLiteHandlers])
 
 
-class SQLServerHandlers(BaseHandlers[SQLServerHandler]):
+class SQLServerHandlers(
+    BaseHandlers[SQLServerHandler[DeclarativeBaseT]], Generic[DeclarativeBaseT]
+):
     pass
 
 
@@ -170,7 +178,7 @@ class SQLHandlers(
 SQLHandlersT = TypeVar("SQLHandlersT", bound=Optional[SQLHandlers])
 
 
-class Handlers(
+class DatabaseHandlers(
     BaseModel,
     Generic[
         NoSQLHandlersT,
@@ -181,4 +189,4 @@ class Handlers(
     sql: Annotated[SQLHandlersT, Field(..., description="SQL handlers")]
 
 
-HandlersT = TypeVar("HandlersT", bound=Optional[Handlers])
+DatabaseHandlersT = TypeVar("DatabaseHandlersT", bound=Optional[DatabaseHandlers])
