@@ -4,7 +4,7 @@ from pymongo import MongoClient
 from redis.asyncio import Redis as AsyncRedis
 from redis import Redis as SyncRedis
 from typing import Generic, Literal, Optional, Tuple, TypeVar, Union, overload
-from maleo.types.base.string import ListOfStrings
+from maleo.types.string import ListOfStrings
 from ..config import (
     ElasticsearchConfig,
     MongoConfig,
