@@ -20,6 +20,8 @@ from typing import (
     overload,
 )
 from uuid import uuid4
+from maleo.logging.enums import Level
+from maleo.logging.logger import EnvironmentT, ServiceKeyT, Database
 from maleo.schemas.application import ApplicationContext, OptionalApplicationContext
 from maleo.schemas.connection import OptionalConnectionContext
 from maleo.schemas.error.enums import Code as ErrorCode
@@ -41,8 +43,7 @@ from maleo.schemas.security.authentication import OptionalAnyAuthentication
 from maleo.schemas.security.authorization import OptionalAnyAuthorization
 from maleo.schemas.security.impersonation import OptionalImpersonation
 from maleo.types.uuid import OptionalUUID
-from maleo.logging.enums import Level
-from maleo.logging.logger import EnvironmentT, ServiceKeyT, Database
+from maleo.utils.exception import extract_details
 from ..enums import Connection
 from ..config import SQLConfigT
 
@@ -68,9 +69,7 @@ class SessionManager(Generic[SQLConfigT]):
             layer=Layer.UTILITY,
             target=Target.DATABASE,
             target_details=self._config.model_dump(
-                exclude={
-                    "connection": {"password"}
-                }
+                exclude={"connection": {"password"}}
             ),
         )
 
@@ -133,13 +132,7 @@ class SessionManager(Generic[SQLConfigT]):
             await session.rollback()
             exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
-                details={
-                    "exc_type": type(se).__name__,
-                    "exc_data": {
-                        "message": str(se),
-                        "args": se.args,
-                    },
-                },
+                details=extract_details(se),
                 operation_type=OperationType.SYSTEM,
                 application_context=self._application_context,
                 operation_id=operation_id,
@@ -180,13 +173,7 @@ class SessionManager(Generic[SQLConfigT]):
             await session.rollback()
             exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
-                details={
-                    "exc_type": type(e).__name__,
-                    "exc_data": {
-                        "message": str(e),
-                        "args": e.args,
-                    },
-                },
+                details=extract_details(e),
                 operation_type=OperationType.SYSTEM,
                 application_context=self._application_context,
                 operation_id=operation_id,
@@ -269,13 +256,7 @@ class SessionManager(Generic[SQLConfigT]):
             session.rollback()  # Rollback on error
             exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
-                details={
-                    "exc_type": type(se).__name__,
-                    "exc_data": {
-                        "message": str(se),
-                        "args": se.args,
-                    },
-                },
+                details=extract_details(se),
                 operation_type=OperationType.SYSTEM,
                 application_context=self._application_context,
                 operation_id=operation_id,
@@ -316,13 +297,7 @@ class SessionManager(Generic[SQLConfigT]):
             session.rollback()  # Rollback on error
             exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
-                details={
-                    "exc_type": type(e).__name__,
-                    "exc_data": {
-                        "message": str(e),
-                        "args": e.args,
-                    },
-                },
+                details=extract_details(e),
                 operation_type=OperationType.SYSTEM,
                 application_context=self._application_context,
                 operation_id=operation_id,
